@@ -9,7 +9,6 @@ use Hash::MoreUtils qw/safe_reverse/;
 use Clustericious::Log;
 use File::Find::Rule;
 use File::Basename qw/dirname/;
-use Data::Dumper;
 use File::Path qw/mkpath/;
 use File::Temp;
 use File::Compare;
@@ -24,7 +23,7 @@ use File::Spec;
 use Yars::Util qw( format_tx_error );
 
 # ABSTRACT: various utility functions dealing with servers, hosts, etc
-our $VERSION = '1.17'; # VERSION
+our $VERSION = '1.18'; # VERSION
 
 
 sub new
@@ -91,7 +90,7 @@ sub refresh_config {
     $self->_write_state({disks => \%disks});
   };
   -e $state_file or LOGDIE "Could not write state file $state_file";
-  TRACE "bucket2url : ".Dumper($self->{bucket_to_url});
+  #TRACE "bucket2url : ".Dumper($self->{bucket_to_url});
 }
 
 sub _dir_is_empty {
@@ -226,7 +225,7 @@ sub server_is_up {
         if (defined($got->{server_version}) && length($got->{server_version})) {
             return ($self->{server_status_cache}->{$server_url}{result} = 1);
         }
-        TRACE "/status did not return version, got : ".Dumper($got);
+        TRACE "/status did not return version, got : ". JSON::MaybeXS::encode_json($got);
         return ($self->{server_status_cache}->{$server_url}{result} = 0);
     }
     TRACE "Server $server_url is not up : response was ".format_tx_error($tx->error);
@@ -436,7 +435,7 @@ Yars::Tools - various utility functions dealing with servers, hosts, etc
 
 =head1 VERSION
 
-version 1.17
+version 1.18
 
 =head1 DESCRIPTION
 
